@@ -19,34 +19,20 @@
  *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
  ***************************************************************************/
 
-#include <sys/time.h>
-
-#include "torkview.h"
-#include "tork.h"
-#include "torclient.h"
-#include <tdelocale.h>
-#include <ntqlabel.h>
-#include <ntqlistview.h>
-#include "dndlistview.h"
-#include "portsandicons.h"
-#include "torkconfig.h"
-#include "chart.h"
-#include "functions.h"
-#include "mixminion.h"
-#include "crypto.h"
-
-#include "hitwidget.h"
-#include "kwidgetlistbox.h"
-#include "kerrylabel.h"
-
-
-#ifndef EXTERNAL_GEOIP
-# include "GeoIP-1.4.0/libGeoIP/GeoIP.h"
-#else
-# include <GeoIP.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
 #endif
 
-#include "kdebug.h"
+#include <tqregexp.h>
+#include <tqsplitter.h>
+#include <tqgroupbox.h>
+#include <tqfile.h>
+#include <tqdir.h>
+#include <tqpixmap.h>
+#include <tqlabel.h>
+#include <tqlistview.h>
+
+#include <kdebug.h>
 #include <kstandarddirs.h>
 #include <kiconloader.h>
 #include <kmimetype.h>
@@ -56,17 +42,38 @@
 #include <krun.h>
 #include <kurl.h>
 #include <tdeio/netaccess.h>
+#include <tdelocale.h>
+
+#if defined(HAVE_SYS_TIME_H)
+# include <sys/time.h>
+#endif
+#if defined(TIME_WITH_SYS_TIME)
+# include <time.h>
+#endif
 
-#include <ntqregexp.h>
-#include <ntqsplitter.h>
-#include <ntqgroupbox.h>
-#include <ntqfile.h>
-#include <ntqdir.h>
-#include <ntqpixmap.h>
 /* Linux-specific includes */
 #include <dirent.h>
 #include <unistd.h>
-#include "../config.h"
+
+#include "torkview.h"
+#include "tork.h"
+#include "torclient.h"
+#include "dndlistview.h"
+#include "portsandicons.h"
+#include "torkconfig.h"
+#include "chart.h"
+#include "functions.h"
+#include "mixminion.h"
+#include "crypto.h"
+#include "hitwidget.h"
+#include "kwidgetlistbox.h"
+#include "kerrylabel.h"
+
+#ifdef EXTERNAL_GEOIP
+# include <GeoIP.h>
+#else
+# include "GeoIP-1.4.0/libGeoIP/GeoIP.h"
+#endif
 
 using namespace tk;
 
@@ -80,15 +87,15 @@ torkView::torkView(TQWidget *parent)
     : torkview_base(parent), m_pop(0L), m_tormon(TorkConfig::showTorMon()), torbtx(0), torbrx(0)
 {
 
-#ifndef EXTERNAL_GEOIP
-    geoip_db = !locate("data", "tork/geoip/GeoIP.dat").isNull();
-#else
+#ifdef EXTERNAL_GEOIP
     GeoIP * gi = 0;
     gi = GeoIP_new(GEOIP_STANDARD);
     if (gi)
         geoip_db = true;
     else
         geoip_db = false;
+#else
+    geoip_db = !locate("data", "tork/geoip/GeoIP.dat").isNull();
 #endif
 
     greenonion << "green" << "up" << "built" << "good" << "connected" << "succeeded";
@@ -274,21 +281,26 @@ void torkView::sendAnonymousEmail() {
 bool torkView::checkInterface() {
 
     bool gotone = false;
-    //Would anyone have this many ethernet cards?
-    TQStringList devices;
-    devices << "eth" << "wlan";
-	for ( TQStringList::Iterator it = devices.begin(); it != devices.end(); ++it ){
-        for (int i=0; i < 5; i++){
-            TQString devpath = TQString("/sys/class/net/%1%2").arg((*it)).arg(i);
-            TQDir ethdir(devpath);
-            if (ethdir.exists()){
-                mSysDevPathList.append(devpath);
-                gotone = true;
-            }else
-                continue;
-        }
-    }
+    TQString sysNet = "/sys/class/net/";
 
+    TQDir dir(sysNet);
+    TQStringList netCard = dir.entryList();
+
+    for ( TQStringList::iterator it = netCard.begin(); it != netCard.end(); it++ )
+    {
+        if( (*it) == "." || (*it) == ".." ) continue;
+
+        TQString netDevice = sysNet + (*it) + "/device";
+        TQDir netPath( netDevice );
+
+        if( netPath.exists() )
+        {
+            TQString ethCard = sysNet + (*it);
+            mSysDevPathList.append(ethCard);
+            gotone = true;
+        }
+
+    }
     return gotone;
 }
 
@@ -931,12 +943,12 @@ TQString torkView::parseStreamPort(const TQString &str_port)
 
         TQString path = "/proc/" +*it+"/fd";
 
-        if ((pdir = opendir((const char*)path)) == NULL)
+        if ((pdir = opendir(path.local8Bit())) == NULL)
             continue;
 
         while ((pde = readdir(pdir)) != NULL) {
 
-            snprintf(fdpath, MAX_PROC_STR_LEN, "/proc/%s/fd/%s", (const char*)*it, pde->d_name);
+            snprintf(fdpath, MAX_PROC_STR_LEN, "/proc/%s/fd/%s", (*it).local8Bit().data(), pde->d_name);
             fdpath[MAX_PROC_STR_LEN - 1] = '\0';
             int len = readlink(fdpath, lbuf, MAX_PROC_STR_LEN);
 
@@ -1011,12 +1023,12 @@ void torkView::ORStatusUpdated(const TQString &ORID, const TQString &status)
 
     if (tmpstatus.contains("closed") || tmpstatus.contains("failed")){
         delete ORline;
-        if (entryGuards[ORID])
+        if (!entryGuards[ORID].isEmpty())
             entryGuards.remove(ORID);
         return;
     }
 
-    if (entryGuards[ORID]){
+    if (!entryGuards[ORID].isEmpty()){
         guardStatusUpdated(ORID, status);
         return;
     }
@@ -1324,17 +1336,17 @@ void torkView::serverStatusUpdated(const TQString &ip,const TQString &fp,
     int country_id = 0;
     GeoIP * gi = 0;
     if (geoip_db)
-#ifndef EXTERNAL_GEOIP
-       gi = GeoIP_open(locate("data", "tork/geoip/GeoIP.dat").ascii(),0);
-#else
+#ifdef EXTERNAL_GEOIP
        gi = GeoIP_new(GEOIP_STANDARD);
+#else
+       gi = GeoIP_open(locate("data", "tork/geoip/GeoIP.dat").ascii(),0);
 #endif
 
     if (gi){
-        country_id = GeoIP_id_by_name(gi, ip);
+        country_id = GeoIP_id_by_name(gi, ip.latin1());
         cc = GeoIP_country_code[country_id];
         GeoIP_delete(gi);
-    
+
         if (!m_countryList.contains(country_id))
             m_countryList << country_id;
     }else
